%m_beispiel_10_2_4_m.m
%Optimierung im Zeitbereich
%Binomial-, Bessel-, Butterworth-Filter

clc, clear, clf
tmax = 70.0; delta_t = 0.001; t = 0:delta_t:tmax;

%Regelstrecke
KS = 2.5; TS1 = 10; TS2 = 4;
%PI-Regler fr Kompensation
TN = TS1;

%Binomial-Filter
KR = TN / (4.0*TS2*KS)
omk = 1.0 / (2.0*TS2)
G_bin = tf (omk^2, [1 2.0*omk omk^2])
G_bin_y = tf([KR KR*(TN+TS2)/(TN*TS2) KR/(TN*TS2)], ...
             [1 1/TS2 KR*KS/(TN*TS2)])
x = step(G_bin, t);
figure (1)
plot(t,x), hold on, grid on
axis ([0 tmax 0 1.1])
xlabel('Zeit  t / s')
ylabel('Sprungantwort  x(t)')
title ('Anwendung von Filter-Vergleichsbertragungsfunktionen')
text (32, 0.88,'Binomial-')
text (32, 0.83,'Filter')
text (17, 0.93,'Bessel-')
text (17, 0.88,'Filter')
text (7, 0.93,'Butterworth-')
text (7, 0.88,'Filter')

%Bessel-Filter
KR = TN / (3.0*TS2*KS)
omk = 1.0 / (3.0*TS2)
G_bes = tf (3.0*omk^2, [1 3.0*omk 3.0*omk^2])
G_bes_y = tf([KR KR*(TN+TS2)/(TN*TS2) KR/(TN*TS2)], ...
             [1 1/TS2 KR*KS/(TN*TS2)])
x = step(G_bes, t);
plot(t,x)

%Butterworth-Filter
KR = TN / (2.0*TS2*KS)
omk = 1.0 / (sqrt(2.0)*TS2)
G_but = tf (omk^2, [1 sqrt(2.0)*omk omk^2])
G_but_y = tf([KR KR*(TN+TS2)/(TN*TS2) KR/(TN*TS2)], ...
             [1 1/TS2 KR*KS/(TN*TS2)])
x = step(G_but, t);
plot(t,x)

figure (2)
x = step(G_bin_y, t);
plot(t,x), hold on, grid on
axis ([0 tmax 0 0.65])
xlabel('Zeit  t / s')
ylabel('Stellgre  y(t)')
title ('Anwendung von Filter-Vergleichsbertragungsfunktionen')
x = step(G_bes_y, t);
plot(t,x)
x = step(G_but_y, t);
plot(t,x)
text (11, 0.88,'Binomial-')
text (11, 0.83,'Filter')
text (17, 0.93,'Bessel-')
text (17, 0.88,'Filter')
text (7, 0.93,'Butterworth-')
text (7, 0.88,'Filter')

%{   
Ergebnisse
Binomial-Filter
KR =     0.2500
omk =    0.1250
Transfer function:
       0.01563
----------------------
s^2 + 0.25 s + 0.01563

Bessel-Filter
KR =     0.3333
omk =    0.0833
Transfer function:
       0.02083
----------------------
s^2 + 0.25 s + 0.02083

Butterworth-Filter
KR =     0.5000
omk =    0.1768
Transfer function:
       0.03125
----------------------
s^2 + 0.25 s + 0.03125
%}